@@ -18,7 +18,7 @@ use super::EXCHANGE_NAME;
 use log::*;
 use serde_json::Value;
 
-const WEBSOCKET_URL: &str = "wss://csocketapi.bitget.com/ws/v1";
+const WEBSOCKET_URL: &str = "wss://ws.bitget.com/mix/v1/stream";
 
 // User has the opinion to subscribe 1 or more channels, total length
 // of multiple channel can not exceeds 4096 bytes.
@@ -26,7 +26,7 @@ const WS_FRAME_SIZE: usize = 4096;
 
 /// The WebSocket client for Bitget swap markets.
 ///
-/// * WebSocket API doc: <https://bitgetlimited.github.io/apidoc/en/swap/#websocketapi>
+/// * WebSocket API doc: <https://bitgetlimited.github.io/apidoc/en/mix/#websocketapi>
 /// * Trading at: <https://www.bitget.com/en/swap/>
 pub struct BitgetSwapWSClient {
     client: WSClientInternal<BitgetMessageHandler>,
